"""
Document loaders for refinire-rag
"""

from .base import Loader, MetadataGenerator
from .universal import UniversalLoader
from .specialized import (
    SpecializedLoader,
    TextLoader,
    MarkdownLoader,
    PDFLoader,
    HTMLLoader,
    CSVLoader,
    JSONLoader
)
from .document_store_loader import DocumentStoreLoader

__all__ = [
    "Loader",
    "MetadataGenerator", 
    "UniversalLoader",
    "SpecializedLoader",
    "TextLoader",
    "MarkdownLoader",
    "PDFLoader",
    "HTMLLoader",
    "CSVLoader",
    "JSONLoader",
    "DocumentStoreLoader",
]